@@ -1,3 +1,5 @@
+from djangofloor.conf.callables import DefaultListenAddress
+
 __author__ = 'Matthieu Gallet'
 
 
@@ -13,5 +15,5 @@ READ_ONLY_MIRROR = True
 USE_CELERY = False
 
 FLOOR_INDEX = 'pythonnest.views.index'
-LISTEN_ADDRESS = 'localhost:8130'
+LISTEN_ADDRESS = DefaultListenAddress(8130)
 FLOOR_TEMPLATE_CONTEXT_PROCESSORS = ['pythonnest.context_processors.context_user', ]
